@@ -23,19 +23,25 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 #include <string>
 
-enum LogLevel {LOG_ERROR, LOG_WARNING, LOG_INFO, LOG_DEBUG};
+enum LogLevel { LOG_ERROR, LOG_WARNING, LOG_INFO, LOG_DEBUG };
 
-			  // using ## gnu extension to allow empty args list
-#define LogError(format, ...)                                        Logger::LogLevelMsg(LOG_ERROR,   format, ## __VA_ARGS__);
-#define LogWarning(format, ...)                                      Logger::LogLevelMsg(LOG_WARNING, format, ## __VA_ARGS__);
-#define LogInfo(format, ...)                                         Logger::LogLevelMsg(LOG_INFO,    format, ## __VA_ARGS__);
+// using ## gnu extension to allow empty args list
+#define LogError(format, ...) \
+  Logger::LogLevelMsg(LOG_ERROR, format, ##__VA_ARGS__);
+#define LogWarning(format, ...) \
+  Logger::LogLevelMsg(LOG_WARNING, format, ##__VA_ARGS__);
+#define LogInfo(format, ...) \
+  Logger::LogLevelMsg(LOG_INFO, format, ##__VA_ARGS__);
 
 // a class using LogDebug must be aware of XMSession
-#define LogDebug(format, ...)   if(XMSession::instance()->debug()) { Logger::LogLevelMsg(LOG_DEBUG,   format, ## __VA_ARGS__); }
+#define LogDebug(format, ...)                              \
+  if (XMSession::instance()->debug()) {                    \
+    Logger::LogLevelMsg(LOG_DEBUG, format, ##__VA_ARGS__); \
+  }
 
 class Logger {
-  public:
-  static void init(const std::string& i_logFile);
+public:
+  static void init();
   static void uninit();
   static bool isInitialized();
 
@@ -43,13 +49,17 @@ class Logger {
   static void setVerbose(bool i_value);
   static void setActiv(bool i_value);
   static void LogLevelMsg(LogLevel i_level, const char *pcFmt, ...);
-  static void LogData(void* data, unsigned int len);
+  static void LogData(void *data, unsigned int len);
 
-  private:
-  static bool  m_isInitialized;
-  static bool  m_verbose;
-  static bool  m_activ;
-  static FILE* m_fd;
+  static void deleteLegacyLog();
+
+private:
+  static bool m_isInitialized;
+  static bool m_verbose;
+  static bool m_activ;
+  static FILE *m_fd;
+
+  static std::string m_logName;
 
   static void LogRaw(const std::string &s);
 };
