@@ -25,24 +25,24 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "StateMenu.h"
 
 class StateHelp : public StateMenu {
-  public:
-  StateHelp(bool drawStateBehind    = true,
-	    bool updateStatesBehind = false,
-	    bool i_gameHelp         = false,
-	    bool i_allowSceneOver = true
-	    );
+public:
+  StateHelp(bool drawStateBehind = true,
+            bool updateStatesBehind = false,
+            bool i_gameHelp = false,
+            bool i_allowSceneOver = true);
   virtual ~StateHelp();
 
+  virtual void enter();
   virtual void leave();
   virtual void enterAfterPop();
 
   /* input */
-  virtual void xmKey(InputEventType i_type, const XMKey& i_xmkey);
+  virtual void xmKey(InputEventType i_type, const XMKey &i_xmkey);
 
- protected:
+protected:
   virtual void checkEvents();
 
- private:
+private:
   /* GUI */
   void createGUI();
 
