@@ -21,34 +21,33 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #ifndef __STATEUPDATE_H__
 #define __STATEUPDATE_H__
 
+#include "../thread/XMThread.h"
 #include "StateManager.h"
 #include "StateWaiting.h"
-#include "../thread/XMThread.h"
 #include <string>
 
 class UIRoot;
 
 class StateUpdate : public StateWaiting {
 public:
-  StateUpdate(bool drawStateBehind,
-	      bool updateStatesBehind);			 
+  StateUpdate(bool drawStateBehind, bool updateStatesBehind);
   virtual ~StateUpdate();
 
   virtual void enter();
   virtual void leave();
 
   virtual bool update();
-  virtual bool updateWhenUnvisible() {return true;}
+  virtual bool updateWhenUnvisible() { return true; }
 
   /* input */
-  virtual void xmKey(InputEventType i_type, const XMKey& i_xmkey);
+  virtual void xmKey(InputEventType i_type, const XMKey &i_xmkey);
 
 protected:
   bool m_threadStarted;
   bool m_threadFinished;
 
   // the thread
-  XMThread*   m_pThread;
+  XMThread *m_pThread;
 
   // the message displayed in the message box if the thread failed
   std::string m_msg;
@@ -64,10 +63,11 @@ protected:
   virtual bool callBeforeLaunchingThread();
 
   // for the message box when a thread badly finished
-  virtual void sendFromMessageBox(const std::string& i_id, UIMsgBoxButton i_button, const std::string& i_input);
-  
-  virtual void onThreadFinishes(bool i_res);
+  virtual void sendFromMessageBox(const std::string &i_id,
+                                  UIMsgBoxButton i_button,
+                                  const std::string &i_input);
 
+  virtual void onThreadFinishes(bool i_res);
 };
 
 #endif
