@@ -22,20 +22,23 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #define __UPGRADELEVELSTHREAD_H__
 
 #include "XMThread.h"
-#include "../WWWAppInterface.h"
+#include "common/WWWAppInterface.h"
 
 class WebLevels;
 class GameState;
 
 class UpgradeLevelsThread : public XMThread, public WWWAppInterface {
 public:
-  UpgradeLevelsThread(const std::string& i_id_theme, bool i_updateAutomaticallyLevels = false);
+  UpgradeLevelsThread(const std::string &i_id_theme,
+                      bool i_loadMainLayerOnly,
+                      bool i_updateAutomaticallyLevels = false);
   virtual ~UpgradeLevelsThread();
 
   void setTaskProgress(float p_percent);
   std::string getMsg() const;
 
-  virtual void setBeingDownloadedInformation(const std::string &p_information,bool p_isNew=true);
+  virtual void setBeingDownloadedInformation(const std::string &p_information,
+                                             bool p_isNew = true);
   virtual bool shouldLevelBeUpdated(const std::string &LevelID);
 
   virtual int realThreadFunction();
@@ -44,12 +47,13 @@ public:
   void setNbLevels(unsigned int i_nb_levels = -1 /* -1 means all */);
 
 private:
-  WebLevels*  m_pWebLevels;
+  WebLevels *m_pWebLevels;
 
   bool m_updateAutomaticallyLevels;
   std::string m_msg;
   std::string m_id_theme; // theme is needed to be able to update it
   int m_nb_levels;
+  bool m_loadMainLayerOnly;
 };
 
 #endif
